@@ -15,10 +15,11 @@ use Time::Local;
 use File::Basename;
 use POSIX qw(strftime);
 use Getopt::Std;
+use if $^O eq "MSWin32", "Win32::Console::ANSI";
 use Term::ANSIColor qw(:constants);
 $Term::ANSIColor::AUTORESET = 1;
 
-my $VERSION = "0.1";
+my $VERSION = "0.2";
 
 my $port;
 my $verbose;
@@ -51,8 +52,9 @@ sub print_help() {
 	      "       The telescope port could be specified with this parameter or TELESCOPE_PORT\n".
 	      "       environment can be set. Defaults depend on the operating system:\n".
 	      "          Linux: /dev/ttyUSB0\n".
-	      "          MacOSX: /dev/cu.usbserial\n".
-	      "          Solaris: /dev/ttya\n"
+	      "          MacOSX: /dev/tty.usbserial\n".
+	      "          Solaris: /dev/ttya\n".
+	      "          Windows: COM1\n";
 }
 
 
@@ -315,7 +317,7 @@ sub setlocation {
 	} elsif ($#params == 2) {
 		$lon = $params[0];
 		$lat = $params[1];
-		$port = $params[3];
+		$port = $params[2];
 
 	} else {
 		print RED "settime: Wrong parameters.\n";
@@ -377,10 +379,11 @@ sub settrack {
 		$tracking = TC_TRACK_EQ_NORTH;
 	} elsif ($mode eq "azalt") {
 		$tracking = TC_TRACK_ALT_AZ;
-	} elsif ($mode == "off") {
+	} elsif ($mode eq "off") {
 		$tracking = TC_TRACK_OFF;
 	} else {
-		print "settrack: Wrong parameters.\n";
+		print RED "settrack: Wrong parameters.\n";
+		return undef;
 	}
 
 	# do not set tracking mode if slewing
@@ -451,7 +454,7 @@ sub gotoeq {
 	} elsif ($#params == 2) {
 		$ra = $params[0];
 		$de = $params[1];
-		$port = $params[3];
+		$port = $params[2];
 
 	} else {
 		print RED "goto: Wrong parameters.\n";
@@ -542,7 +545,7 @@ sub gotoaz {
 	} elsif ($#params == 2) {
 		$az = $params[0];
 		$alt = $params[1];
-		$port = $params[3];
+		$port = $params[2];
 
 	} else {
 		print RED "gotoaz: Wrong parameters.\n";
@@ -659,9 +662,11 @@ sub main() {
 		if ($^O eq 'linux') {
 			$port = "/dev/ttyUSB0";
 		} elsif ($^O eq 'darwin') {
-			$port = "/dev/cu.usbserial";
+			$port = "/dev/tty.usbserial";
 		} elsif ($^O eq 'solaris') {
 			$port = "/dev/ttya";
+		} elsif ($^O eq 'MSWin32') {
+			$port = "COM1";
 		}
 	}
 
